==> pulumi-azure-native-kotlin-2.19.0.0-sources.jar: com/pulumi/azurenative/scvmm/kotlin/inputs/VirtualMachineInstancePropertiesAvailabilitySetsArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.scvmm.kotlin.inputs

import com.pulumi.azurenative.scvmm.inputs.VirtualMachineInstancePropertiesAvailabilitySetsArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.String
import kotlin.Suppress
import kotlin.jvm.JvmName

/**
 * Availability Set model
 * @property id Gets the ARM Id of the microsoft.scvmm/availabilitySets resource.
 * @property name Gets or sets the name of the availability set.
 */
public data class VirtualMachineInstancePropertiesAvailabilitySetsArgs(
    public val id: Output<String>? = null,
    public val name: Output<String>? = null,
) :
    ConvertibleToJava<com.pulumi.azurenative.scvmm.inputs.VirtualMachineInstancePropertiesAvailabilitySetsArgs> {
    override fun toJava():
        com.pulumi.azurenative.scvmm.inputs.VirtualMachineInstancePropertiesAvailabilitySetsArgs =
        com.pulumi.azurenative.scvmm.inputs.VirtualMachineInstancePropertiesAvailabilitySetsArgs.builder()
            .id(id?.applyValue({ args0 -> args0 }))
            .name(name?.applyValue({ args0 -> args0 })).build()
}

/**
 * Builder for [VirtualMachineInstancePropertiesAvailabilitySetsArgs].
 */
@PulumiTagMarker
public class VirtualMachineInstancePropertiesAvailabilitySetsArgsBuilder internal constructor() {
    private var id: Output<String>? = null

    private var name: Output<String>? = null

    /**
     * @param value Gets the ARM Id of the microsoft.scvmm/availabilitySets resource.
     */
    @JvmName("uuhsqmcckqyrhvaw")
    public suspend fun id(`value`: Output<String>) {
        this.id = value
    }

    /**
     * @param value Gets or sets the name of the availability set.
     */
    @JvmName("mfrolslsuurrxtpw")
    public suspend fun name(`value`: Output<String>) {
        this.name = value
    }

    /**
     * @param value Gets the ARM Id of the microsoft.scvmm/availabilitySets resource.
     */
    @JvmName("gruitymfgilywocx")
    public suspend fun id(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.id = mapped
    }

    /**
     * @param value Gets or sets the name of the availability set.
     */
    @JvmName("vltbvykwmpuvowpg")
    public suspend fun name(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.name = mapped
    }

    internal fun build(): VirtualMachineInstancePropertiesAvailabilitySetsArgs =
        VirtualMachineInstancePropertiesAvailabilitySetsArgs(
            id = id,
            name = name,
        )
}

==> pulumi-azure-native-kotlin-2.28.0.0-sources.jar: com/pulumi/azurenative/scvmm/kotlin/inputs/VirtualMachineInstancePropertiesAvailabilitySetsArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.scvmm.kotlin.inputs

import com.pulumi.azurenative.scvmm.inputs.VirtualMachineInstancePropertiesAvailabilitySetsArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.String
import kotlin.Suppress
import kotlin.jvm.JvmName

/**
 * Availability Set model
 * @property id Gets the ARM Id of the microsoft.scvmm/availabilitySets resource.
 * @property name Gets or sets the name of the availability set.
 */
public data class VirtualMachineInstancePropertiesAvailabilitySetsArgs(
    public val id: Output<String>? = null,
    public val name: Output<String>? = null,
) :
    ConvertibleToJava<com.pulumi.azurenative.scvmm.inputs.VirtualMachineInstancePropertiesAvailabilitySetsArgs> {
    override fun toJava():
        com.pulumi.azurenative.scvmm.inputs.VirtualMachineInstancePropertiesAvailabilitySetsArgs =
        com.pulumi.azurenative.scvmm.inputs.VirtualMachineInstancePropertiesAvailabilitySetsArgs.builder()
            .id(id?.applyValue({ args0 -> args0 }))
            .name(name?.applyValue({ args0 -> args0 })).build()
}

/**
 * Builder for [VirtualMachineInstancePropertiesAvailabilitySetsArgs].
 */
@PulumiTagMarker
public class VirtualMachineInstancePropertiesAvailabilitySetsArgsBuilder internal constructor() {
    private var id: Output<String>? = null

    private var name: Output<String>? = null

    /**
     * @param value Gets the ARM Id of the microsoft.scvmm/availabilitySets resource.
     */
    @JvmName("ectdgsvnpteyolei")
    public suspend fun id(`value`: Output<String>) {
        this.id = value
    }

    /**
     * @param value Gets or sets the name of the availability set.
     */
    @JvmName("amiudotrlxwyqbvh")
    public suspend fun name(`value`: Output<String>) {
        this.name = value
    }

    /**
     * @param value Gets the ARM Id of the microsoft.scvmm/availabilitySets resource.
     */
    @JvmName("fgqsgnqlmulqbyif")
    public suspend fun id(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.id = mapped
    }

    /**
     * @param value Gets or sets the name of the availability set.
     */
    @JvmName("dwvmmmyhskeudris")
    public suspend fun name(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.name = mapped
    }

    internal fun build(): VirtualMachineInstancePropertiesAvailabilitySetsArgs =
        VirtualMachineInstancePropertiesAvailabilitySetsArgs(
            id = id,
            name = name,
        )
}
